import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ACMClient";
import { ListTagsForCertificateRequest, ListTagsForCertificateResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListTagsForCertificateCommand}.
 */
export interface ListTagsForCertificateCommandInput extends ListTagsForCertificateRequest {
}
/**
 * @public
 *
 * The output of {@link ListTagsForCertificateCommand}.
 */
export interface ListTagsForCertificateCommandOutput extends ListTagsForCertificateResponse, __MetadataBearer {
}
declare const ListTagsForCertificateCommand_base: {
    new (input: ListTagsForCertificateCommandInput): import("@smithy/smithy-client").CommandImpl<ListTagsForCertificateCommandInput, ListTagsForCertificateCommandOutput, ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListTagsForCertificateCommandInput): import("@smithy/smithy-client").CommandImpl<ListTagsForCertificateCommandInput, ListTagsForCertificateCommandOutput, ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the tags that have been applied to the ACM certificate. Use the certificate's
 *       Amazon Resource Name (ARN) to specify the certificate. To add a tag to an ACM certificate,
 *       use the <a>AddTagsToCertificate</a> action. To delete a tag, use the <a>RemoveTagsFromCertificate</a> action. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ACMClient, ListTagsForCertificateCommand } from "@aws-sdk/client-acm"; // ES Modules import
 * // const { ACMClient, ListTagsForCertificateCommand } = require("@aws-sdk/client-acm"); // CommonJS import
 * const client = new ACMClient(config);
 * const input = { // ListTagsForCertificateRequest
 *   CertificateArn: "STRING_VALUE", // required
 * };
 * const command = new ListTagsForCertificateCommand(input);
 * const response = await client.send(command);
 * // { // ListTagsForCertificateResponse
 * //   Tags: [ // TagList
 * //     { // Tag
 * //       Key: "STRING_VALUE", // required
 * //       Value: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListTagsForCertificateCommandInput - {@link ListTagsForCertificateCommandInput}
 * @returns {@link ListTagsForCertificateCommandOutput}
 * @see {@link ListTagsForCertificateCommandInput} for command's `input` shape.
 * @see {@link ListTagsForCertificateCommandOutput} for command's `response` shape.
 * @see {@link ACMClientResolvedConfig | config} for ACMClient's `config` shape.
 *
 * @throws {@link InvalidArnException} (client fault)
 *  <p>The requested Amazon Resource Name (ARN) does not refer to an existing resource.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified certificate cannot be found in the caller's account or the caller's account
 *       cannot be found.</p>
 *
 * @throws {@link ACMServiceException}
 * <p>Base exception class for all service exceptions from ACM service.</p>
 *
 *
 * @public
 */
export declare class ListTagsForCertificateCommand extends ListTagsForCertificateCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListTagsForCertificateRequest;
            output: ListTagsForCertificateResponse;
        };
        sdk: {
            input: ListTagsForCertificateCommandInput;
            output: ListTagsForCertificateCommandOutput;
        };
    };
}
