import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ACMClient";
import { UpdateCertificateOptionsRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateCertificateOptionsCommand}.
 */
export interface UpdateCertificateOptionsCommandInput extends UpdateCertificateOptionsRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateCertificateOptionsCommand}.
 */
export interface UpdateCertificateOptionsCommandOutput extends __MetadataBearer {
}
declare const UpdateCertificateOptionsCommand_base: {
    new (input: UpdateCertificateOptionsCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateCertificateOptionsCommandInput, UpdateCertificateOptionsCommandOutput, ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: UpdateCertificateOptionsCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateCertificateOptionsCommandInput, UpdateCertificateOptionsCommandOutput, ACMClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates a certificate. Currently, you can use this function to specify whether to opt in
 *       to or out of recording your certificate in a certificate transparency log. For more
 *       information, see <a href="https://docs.aws.amazon.com/acm/latest/userguide/acm-bestpractices.html#best-practices-transparency"> Opting Out of
 *         Certificate Transparency Logging</a>. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ACMClient, UpdateCertificateOptionsCommand } from "@aws-sdk/client-acm"; // ES Modules import
 * // const { ACMClient, UpdateCertificateOptionsCommand } = require("@aws-sdk/client-acm"); // CommonJS import
 * const client = new ACMClient(config);
 * const input = { // UpdateCertificateOptionsRequest
 *   CertificateArn: "STRING_VALUE", // required
 *   Options: { // CertificateOptions
 *     CertificateTransparencyLoggingPreference: "ENABLED" || "DISABLED",
 *   },
 * };
 * const command = new UpdateCertificateOptionsCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateCertificateOptionsCommandInput - {@link UpdateCertificateOptionsCommandInput}
 * @returns {@link UpdateCertificateOptionsCommandOutput}
 * @see {@link UpdateCertificateOptionsCommandInput} for command's `input` shape.
 * @see {@link UpdateCertificateOptionsCommandOutput} for command's `response` shape.
 * @see {@link ACMClientResolvedConfig | config} for ACMClient's `config` shape.
 *
 * @throws {@link InvalidArnException} (client fault)
 *  <p>The requested Amazon Resource Name (ARN) does not refer to an existing resource.</p>
 *
 * @throws {@link InvalidStateException} (client fault)
 *  <p>Processing has reached an invalid state.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>An ACM quota has been exceeded.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified certificate cannot be found in the caller's account or the caller's account
 *       cannot be found.</p>
 *
 * @throws {@link ACMServiceException}
 * <p>Base exception class for all service exceptions from ACM service.</p>
 *
 *
 * @public
 */
export declare class UpdateCertificateOptionsCommand extends UpdateCertificateOptionsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdateCertificateOptionsRequest;
            output: {};
        };
        sdk: {
            input: UpdateCertificateOptionsCommandInput;
            output: UpdateCertificateOptionsCommandOutput;
        };
    };
}
